// pages/index.tsx
import { useState } from 'react';
import { FaPlane, FaHotel, FaPassport, FaExchangeAlt } from 'react-icons/fa';
import DatePicker from 'react-datepicker';
import 'react-datepicker/dist/react-datepicker.css';

const airports = [
  { city: 'Dhaka', code: 'DAC', name: 'Hazrat Shahjalal International Airport' },
  { city: 'Chittagong', code: 'CGP', name: 'Shah Amanat International Airport' },
  { city: 'Sylhet', code: 'ZYL', name: 'Osmani International Airport' },
  // Add more airports as needed
];

export default function VisaBooking() {
  const [searchType, setSearchType] = useState('Flight');
  const [tripType, setTripType] = useState('One Way');
  const [from, setFrom] = useState('Dhaka');
  const [to, setTo] = useState('Chittagong');
  const [departure, setDeparture] = useState(new Date());
  const [returnDate, setReturnDate] = useState<Date | null>(null);
  const [travelers, setTravelers] = useState('1 Traveler');
  const [fareType, setFareType] = useState('Regular Fares');

  const handleSearch = () => {
    // Implement your search logic here
    console.log({
      searchType,
      tripType,
      from,
      to,
      departure,
      returnDate,
      travelers,
      fareType,
    });
  };

  return (
    <div className="min-h-screen bg-gray-100 p-8">
      <div className="max-w-4xl mx-auto bg-white rounded-lg shadow-lg p-6">
        <div className="flex space-x-4 mb-6">
          {['Flight', 'Hotel', 'Visa'].map((type) => (
            <button
              key={type}
              className={`flex items-center px-4 py-2 rounded-md ${
                searchType === type ? 'bg-red-100 text-red-600' : 'bg-gray-100'
              }`}
              onClick={() => setSearchType(type)}
            >
              {type === 'Flight' && <FaPlane className="mr-2" />}
              {type === 'Hotel' && <FaHotel className="mr-2" />}
              {type === 'Visa' && <FaPassport className="mr-2" />}
              {type}
            </button>
          ))}
        </div>

        <div className="flex space-x-4 mb-6">
          {['One Way', 'Round Trip', 'Multi City'].map((type) => (
            <label key={type} className="flex items-center">
              <input
                type="radio"
                name="tripType"
                value={type}
                checked={tripType === type}
                onChange={() => setTripType(type)}
                className="mr-2"
              />
              <span>{type}</span>
            </label>
          ))}
        </div>

        <div className="grid grid-cols-2 gap-4 mb-4">
          <div>
            <label className="block text-sm font-medium text-gray-700">From</label>
            <select
              value={from}
              onChange={(e) => setFrom(e.target.value)}
              className="mt-1 block w-full rounded-md border-gray-300 shadow-sm"
            >
              {airports.map((airport) => (
                <option key={airport.code} value={airport.city}>
                  {airport.name} ({airport.city})
                </option>
              ))}
            </select>
          </div>
          <div className="relative">
            <label className="block text-sm font-medium text-gray-700">To</label>
            <select
              value={to}
              onChange={(e) => setTo(e.target.value)}
              className="mt-1 block w-full rounded-md border-gray-300 shadow-sm"
            >
              {airports.map((airport) => (
                <option key={airport.code} value={airport.city}>
                  {airport.name} ({airport.city})
                </option>
              ))}
            </select>
            <button
              className="absolute top-1/2 -left-6 transform -translate-y-1/2 bg-red-100 rounded-full p-2"
              onClick={() => {
                const temp = from;
                setFrom(to);
                setTo(temp);
              }}
            >
              <FaExchangeAlt className="text-red-600" />
            </button>
          </div>
        </div>

        <div className="grid grid-cols-3 gap-4 mb-6">
          <div>
            <label className="block text-sm font-medium text-gray-700">Departure</label>
            <DatePicker
              selected={departure}
              onChange={(date) => setDeparture(date as Date)}
              className="mt-1 block w-full rounded-md border-gray-300 shadow-sm"
            />
          </div>
          <div>
            <label className="block text-sm font-medium text-gray-700">Return</label>
            <DatePicker
              selected={returnDate}
              onChange={(date) => setReturnDate(date as Date)}
              className="mt-1 block w-full rounded-md border-gray-300 shadow-sm"
              disabled={tripType === 'One Way'}
            />
          </div>
          <div>
            <label className="block text-sm font-medium text-gray-700">Travelers & Booking Class</label>
            <select
              value={travelers}
              onChange={(e) => setTravelers(e.target.value)}
              className="mt-1 block w-full rounded-md border-gray-300 shadow-sm"
            >
              <option>1 Traveler</option>
              <option>2 Travelers</option>
              <option>3 Travelers</option>
            </select>
          </div>
        </div>

        <div className="flex space-x-4 mb-6">
          {['Regular Fares', 'Umrah Fares', 'Student Fares', 'Seaman Fares'].map((type) => (
            <label key={type} className="flex items-center">
              <input
                type="radio"
                name="fareType"
                value={type}
                checked={fareType === type}
                onChange={() => setFareType(type)}
                className="mr-2"
              />
              <span>{type}</span>
            </label>
          ))}
        </div>

        <button
          onClick={handleSearch}
          className="w-full bg-red-500 text-white py-2 rounded-md hover:bg-red-600 transition duration-300"
        >
          Search
        </button>
      </div>
    </div>
  );
}
